<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Circle3T</name>
    <message>
        <location filename="../Circle3T.js" line="+84"/>
        <source>First line, arc or circle</source>
        <translation>第一条直线，弧或圆</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Second line, arc or circle</source>
        <translation>第二条直线，弧或圆</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Third line, arc or circle</source>
        <translation>第三条直线，弧或圆</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation>选择方案</translation>
    </message>
    <message>
        <location line="+116"/>
        <location line="+61"/>
        <source>No solution</source>
        <translation>无方案</translation>
    </message>
    <message>
        <location filename="../Circle3TInit.js" line="+2"/>
        <source>3 T&amp;angents</source>
        <translation>3 切线(&amp;a)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to three entities</source>
        <translation>画三实体的公切圆</translation>
    </message>
</context>
</TS>
